aind-watchdog-service
----------------------

.. automodule:: aind_watchdog_service.alert_bot
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: aind_watchdog_service.event_handler
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: aind_watchdog_service.logging_config
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: aind_watchdog_service.main
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: aind_watchdog_service.run_job
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: aind_watchdog_service.models
   :members:
   :undoc-members:
   :show-inheritance:
